MenuEvent

Struct MenuEvent 

pub struct MenuEvent {
    pub source: Entity,
    pub action: MenuAction,
}
Event used to control the state of the open menu. This bubbles upwards from the menu items and the menu container, through the portal relation, and to the menu owner entity.

Focus navigation: the menu may be part of a composite of multiple menus such as a menu bar. This means that depending on direction, focus movement may move to the next menu item, or the next menu. This also means that different events will often be handled at different levels of the hierarchy - some being handled by the popup, and some by the popup’s owner.

Fields

source: Entity

The MenuItem or MenuPopup that triggered this event.

action: MenuAction

The desired action in response to this event.